@@ -19,8 +19,8 @@
 
 KGmap::KGmap()
 {
-	p_capitalToDivisionPattern = kli18nc("@title:group", "%1 is the capital of...").untranslatedText();
-	p_divisionToCapitalPattern = kli18nc("@title:group", "The capital of %1 is...").untranslatedText();
+	p_capitalToDivisionPattern = QString::fromUtf8(kli18nc("@title:group", "%1 is the capital of...").untranslatedText());
+	p_divisionToCapitalPattern = QString::fromUtf8(kli18nc("@title:group", "The capital of %1 is...").untranslatedText());
 }
 
 KGmap::~KGmap()
@@ -92,7 +92,7 @@ void KGmap::setDivisionToCapitalTitle(const QString &str)
 uint KGmap::count(division::askMode am) const
 {
 	uint count = 0;
-	foreach(const division *d, p_divisions)
+	for(const division *d : p_divisions)
 	{
 		if (d->canAsk(am)) count++;
 	}
@@ -101,12 +101,12 @@ uint KGmap::count(division::askMode am) const
 
 KLocalizedString KGmap::getCapitalToDivisionQuestionPattern() const
 {
-	return ki18nc("@title:group", p_capitalToDivisionPattern.toUtf8());
+	return ki18nc("@title:group", p_capitalToDivisionPattern.toUtf8().constData());
 }
 
 KLocalizedString KGmap::getDivisionToCapitalQuestionPattern() const
 {
-	return ki18nc("@title:group", p_divisionToCapitalPattern.toUtf8());
+	return ki18nc("@title:group", p_divisionToCapitalPattern.toUtf8().constData());
 }
 
 QString KGmap::getCapitalToDivisionTitle() const
@@ -182,7 +182,7 @@ QColor KGmap::getColor(const QString &s) const
 QList<const division*> KGmap::getIgnoredDivisions(division::askMode am) const
 {
 	QList<const division*> ignoredDivisions;
-	foreach (division* div, p_divisions)
+	for (division* div : p_divisions)
 		if (!div->canAsk(am))
 			ignoredDivisions << div;
 	return ignoredDivisions;
@@ -191,14 +191,14 @@ QList<const division*> KGmap::getIgnoredDivisions(division::askMode am) const
 QList<const division*> KGmap::getAllDivisionsOrdered() const
 {
 	QList<const division*> constDivisions;
-	foreach (const division* div, p_divisions)
+	for (const division* div : p_divisions)
 		constDivisions << div;
 	return constDivisions;
 }
 
 division *KGmap::getDivision(const QString &divisionName) const
 {
-	foreach (division* div, p_divisions)
+	for (division* div : p_divisions)
 	{
 		if (div->getUntranslatedName() == divisionName) return div;
 	}
@@ -207,7 +207,7 @@ division *KGmap::getDivision(const QString &divisionName) const
 
 division *KGmap::getDivision(QRgb c) const
 {
-	foreach (division* div, p_divisions)
+	for (division* div : p_divisions)
 	{
 		if (div->getRGB() == c) return div;
 	}
